@@ -1,34 +1,26 @@
-# XXX RULES FOR PATCHING THIS FILE XXX
-# Patches that fix typos or formatting are acceptable.  Patches
-# that change semantics are not acceptable without prior approval
-# by David Golden or Ricardo Signes.
-
+# vi:tw=72
 use 5.006;
 use strict;
 use warnings;
 package CPAN::Meta::Spec;
-# VERSION
-$CPAN::Meta::Spec::VERSION = '2.143240';
+our $VERSION = '2.120351'; # VERSION
+
 1;
 
 # ABSTRACT: specification for CPAN distribution metadata
 
 
-# vi:tw=72
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 CPAN::Meta::Spec - specification for CPAN distribution metadata
 
 =head1 VERSION
 
-version 2.143240
+version 2.120351
 
 =head1 SYNOPSIS
 
@@ -82,7 +74,7 @@ version 2.143240
     keywords => [ qw/ toolchain cpan dual-life / ],
     'meta-spec' => {
       version => '2',
-      url     => 'https://metacpan.org/pod/CPAN::Meta::Spec',
+      url     => 'http://search.cpan.org/perldoc?CPAN::Meta::Spec',
     },
     generated_by => 'Module::Build version 0.36',
   };
@@ -289,17 +281,11 @@ etc.) as part of its configuration.  This field should be set to a false
 value to indicate that prerequisites included in metadata may be
 considered final and valid for static analysis.
 
-Note: when this field is true, post-configuration prerequisites are not
-guaranteed to bear any relation whatsoever to those stated in the metadata,
-and relying on them doing so is an error. See also
-L</Prerequisites for dynamically configured distributions> in the implementors'
-notes.
-
 This field explicitly B<does not> indicate whether installation may be
 safely performed without using a Makefile or Build file, as there may be
 special files to install or custom installation targets (e.g. for
 dual-life modules that exist on CPAN as well as in the Perl core).  This
-field only defines whether or not prerequisites are exactly as given in the
+field only defines whether prerequisites are complete as given in the
 metadata.
 
 =head3 generated_by
@@ -321,7 +307,7 @@ Example:
 
   license => [ 'perl_5' ]
 
-  license => [ 'apache_2_0', 'mozilla_1_0' ]
+  license => [ 'apache_2', 'mozilla_1_0' ]
 
 (Spec 2) [required] {List of one or more License Strings}
 
@@ -401,20 +387,6 @@ This is a I<URL> of the metadata specification document corresponding to
 the given version.  This is strictly for human-consumption and should
 not impact the interpretation of the document.
 
-For the version 2 spec, either of these are recommended:
-
-=over 4
-
-=item *
-
-C<https://metacpan.org/pod/CPAN::Meta::Spec>
-
-=item *
-
-C<http://search.cpan.org/perldoc?CPAN::Meta::Spec>
-
-=back
-
 =back
 
 =head3 name
@@ -428,8 +400,7 @@ Example:
 This field is the name of the distribution.  This is often created by
 taking the "main package" in the distribution and changing C<::> to
 C<->, but the name may be completely unrelated to the packages within
-the distribution.  For example, L<LWP::UserAgent> is distributed as part
-of the distribution name "libwww-perl".
+the distribution.  C.f. L<http://search.cpan.org/dist/libwww-perl/>.
 
 =head3 release_status
 
@@ -526,10 +497,7 @@ Example:
 
 This Map describes any files, directories, packages, and namespaces that
 are private to the packaging or implementation of the distribution and
-should be ignored by indexing or search tools. Note that this is a list of
-exclusions, and the spec does not define what to I<include> - see
-L</Indexing distributions a la PAUSE> in the implementors notes for more
-information.
+should be ignored by indexing or search tools.
 
 Valid subkeys are as follows:
 
@@ -617,7 +585,7 @@ I<Suggestion for disuse:> Because there is currently no way for a
 distribution to specify a dependency on an optional feature of another
 dependency, the use of C<optional_feature> is discouraged.  Instead,
 create a separate, installable distribution that ensures the desired
-feature is available.  For example, if C<Foo::Bar> has a C<Baz> feature,
+feature is available.  For example, if C<Foo::Bar> has a "Baz" feature,
 release a separate C<Foo-Bar-Baz> distribution that satisfies
 requirements for the feature.
 
@@ -671,14 +639,14 @@ Example:
   provides => {
     'Foo::Bar' => {
       file    => 'lib/Foo/Bar.pm',
-      version => '0.27_02',
+      version => 0.27_02
     },
     'Foo::Bar::Blah' => {
       file    => 'lib/Foo/Bar/Blah.pm',
     },
     'Foo::Bar::Baz' => {
       file    => 'lib/Foo/Bar/Baz.pm',
-      version => '0.3',
+      version => 0.3,
     },
   }
 
@@ -686,27 +654,23 @@ Example:
 
 This describes all packages provided by this distribution.  This
 information is used by distribution and automation mechanisms like
-PAUSE, CPAN, metacpan.org and search.cpan.org to build indexes saying in
-which distribution various packages can be found.
+PAUSE, CPAN, and search.cpan.org to build indexes saying in which
+distribution various packages can be found.
 
 The keys of C<provides> are package names that can be found within
-the distribution.  If a package name key is provided, it must
-have a Map with the following valid subkeys:
+the distribution.  The values are Maps with the following valid subkeys:
 
 =over
 
 =item file
 
-This field is required.  It must contain a Unix-style relative file path
-from the root of the distribution directory to a file that contains or
-generates the package.  It may be given as C<META.yml> or C<META.json>
-to claim a package for indexing without needing a C<*.pm>.
+This field is required.  The value must contain a Unix-style relative
+file path from the root of the distribution to the module containing the
+package.
 
 =item version
 
-If it exists, this field must contains a I<Version> String for the
-package.  If the package does not have a C<$VERSION>, this field must
-be omitted.
+This field contains a I<Version> String for the package, if one exists.
 
 =back
 
@@ -767,8 +731,7 @@ is a Map with the following valid keys:
 Because a url like C<http://myrepo.example.com/> is ambiguous as to
 type, producers should provide a C<type> whenever a C<url> key is given.
 The C<type> field should be the name of the most common program used
-to work with the repository, e.g. C<git>, C<svn>, C<cvs>, C<darcs>,
-C<bzr> or C<hg>.
+to work with the repository, e.g. git, svn, cvs, darcs, bzr or hg.
 
 =back
 
@@ -1029,7 +992,7 @@ described in the L<Version Ranges> section.
 Another subtle error that can occur in resolving prerequisites comes from
 the way that modules in prerequisites are indexed to distribution files on
 CPAN.  When a module is deleted from a distribution, prerequisites calling
-for that module could indicate an older distribution should be installed,
+for that module could indicate an older distribution should installed,
 potentially overwriting files from a newer distribution.
 
 For example, as of Oct 31, 2009, the CPAN index file contained these
@@ -1113,91 +1076,25 @@ and version prerequisite C<$prereq>:
 If the values of C<$mod> and C<$prereq> have not been scrubbed, however,
 this presents security implications.
 
-=head2 Prerequisites for dynamically configured distributions
-
-When C<dynamic_config> is true, it is an error to presume that the
-prerequisites given in distribution metadata will have any relationship
-whatsoever to the actual prerequisites of the distribution.
-
-In practice, however, one can generally expect such prerequisites to be
-one of two things:
-
-=over 4
-
-=item *
-
-The minimum prerequisites for the distribution, to which dynamic configuration will only add items
-
-=item *
-
-Whatever the distribution configured with on the releaser's machine at release time
-
-=back
-
-The second case often turns out to have identical results to the first case,
-albeit only by accident.
-
-As such, consumers may use this data for informational analysis, but
-presenting it to the user as canonical or relying on it as such is
-invariably the height of folly.
-
-=head2 Indexing distributions a la PAUSE
-
-While no_index tells you what must be ignored when indexing, this spec holds
-no opinion on how you should get your initial candidate list of things to
-possibly index. For "normal" distributions you might consider simply indexing
-the contents of lib/, but there are many fascinating oddities on CPAN and
-many dists from the days when it was normal to put the main .pm file in the
-root of the distribution archive - so PAUSE currently indexes all .pm and .PL
-files that are not either (a) specifically excluded by no_index (b) in
-C<inc>, C<xt>, or C<t> directories, or common 'mistake' directories such as
-C<perl5>.
-
-Or: If you're trying to be PAUSE-like, make sure you skip C<inc>, C<xt> and
-C<t> as well as anything marked as no_index.
-
-Also remember: If the META file contains a provides field, you shouldn't be
-indexing anything in the first place - just use that.
-
 =head1 SEE ALSO
 
-=over 4
-
-=item *
-
 CPAN, L<http://www.cpan.org/>
 
-=item *
+CPAN.pm, L<http://search.cpan.org/dist/CPAN/>
+
+CPANPLUS, L<http://search.cpan.org/dist/CPANPLUS/>
+
+ExtUtils::MakeMaker, L<http://search.cpan.org/dist/ExtUtils-MakeMaker/>
+
+Module::Build, L<http://search.cpan.org/dist/Module-Build/>
+
+Module::Install, L<http://search.cpan.org/dist/Module-Install/>
 
 JSON, L<http://json.org/>
 
-=item *
-
 YAML, L<http://www.yaml.org/>
 
-=item *
-
-L<CPAN>
-
-=item *
-
-L<CPANPLUS>
-
-=item *
-
-L<ExtUtils::MakeMaker>
-
-=item *
-
-L<Module::Build>
-
-=item *
-
-L<Module::Install>
-
-=back
-
-=head1 HISTORY
+=head1 CONTRIBUTORS
 
 Ken Williams wrote the original CPAN Meta Spec (also known as the
 "META.yml spec") in 2003 and maintained it through several revisions
@@ -1210,6 +1107,21 @@ process.  David and Ricardo Signes drafted the final version 2 spec
 in April 2010 based on the version 1.4 spec and patches contributed
 during the proposal process.
 
+Several others have contributed patches over the years.  The full list
+of contributors in the repository history currently includes:
+
+  2shortplanks
+  Avar Arnfjord Bjarmason
+  Christopher J. Madsen
+  Damyan Ivanov
+  David Golden
+  Eric Wilhelm
+  Ken Williams
+  Lars DIECKOW
+  Michael G. Schwern
+  Randy Sims
+  Ricardo Signes
+
 =head1 AUTHORS
 
 =over 4
@@ -1232,3 +1144,4 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
