@@ -1,9 +1,7 @@
 package ExtUtils::MM_Any;
 
 use strict;
-use warnings;
-our $VERSION = '7.77_03';
-$VERSION =~ tr/_//d;
+our $VERSION = '7.04';
 
 use Carp;
 use File::Spec;
@@ -11,7 +9,7 @@ use File::Basename;
 BEGIN { our @ISA = qw(File::Spec); }
 
 # We need $Verbose
-use ExtUtils::MakeMaker qw($Verbose neatvalue _sprintf562);
+use ExtUtils::MakeMaker qw($Verbose);
 
 use ExtUtils::MakeMaker::Config;
 
@@ -19,10 +17,9 @@ use ExtUtils::MakeMaker::Config;
 # So we don't have to keep calling the methods over and over again,
 # we have these globals to cache the values.  Faster and shrtr.
 my $Curdir  = __PACKAGE__->curdir;
-#my $Updir   = __PACKAGE__->updir;
+my $Rootdir = __PACKAGE__->rootdir;
+my $Updir   = __PACKAGE__->updir;
 
-my $METASPEC_URL = 'https://metacpan.org/pod/CPAN::Meta::Spec';
-my $METASPEC_V = 2;
 
 =head1 NAME
 
@@ -47,7 +44,7 @@ ExtUtils::MM_Any is a superclass for the ExtUtils::MM_* set of
 modules.  It contains methods which are either inherently
 cross-platform or are written in a cross-platform manner.
 
-Subclass off of ExtUtils::MM_Any I<and> L<ExtUtils::MM_Unix>.  This is a
+Subclass off of ExtUtils::MM_Any I<and> ExtUtils::MM_Unix.  This is a
 temporary solution.
 
 B<THIS MAY BE TEMPORARY!>
@@ -196,7 +193,7 @@ sub can_redirect_error {
 
     my $is_dmake = $self->is_make_type('dmake');
 
-Returns true if C<< $self->make >> is the given type; possibilities are:
+Returns true if C<<$self->make>> is the given type; possibilities are:
 
   gmake    GNU make
   dmake
@@ -205,28 +202,19 @@ Returns true if C<< $self->make >> is the given type; possibilities are:
 
 =cut
 
-my %maketype2true;
-# undocumented - so t/cd.t can still do its thing
-sub _clear_maketype_cache { %maketype2true = () }
-
 sub is_make_type {
     my($self, $type) = @_;
-    return $maketype2true{$type} if defined $maketype2true{$type};
     (undef, undef, my $make_basename) = $self->splitpath($self->make);
-    return $maketype2true{$type} = 1
-        if $make_basename =~ /\b$type\b/i; # executable's filename
-    return $maketype2true{$type} = 0
-        if $make_basename =~ /\b[gdn]make\b/i; # Never fall through for dmake/nmake/gmake
+    return 1 if $make_basename =~ /\b$type\b/i; # executable's filename
+    return 0 if $make_basename =~ /\b(dmake|nmake)\b/i; # Never fall through for dmake/nmake
     # now have to run with "-v" and guess
     my $redirect = $self->can_redirect_error ? '2>&1' : '';
     my $make = $self->make || $self->{MAKE};
     my $minus_v = `"$make" -v $redirect`;
-    return $maketype2true{$type} = 1
-        if $type eq 'gmake' and $minus_v =~ /GNU make/i;
-    return $maketype2true{$type} = 1
-        if $type eq 'bsdmake'
-      and $minus_v =~ /^usage:.*make\s*\[-B/im;
-    $maketype2true{$type} = 0; # it wasn't whatever you asked
+    return 1 if $type eq 'gmake' and $minus_v =~ /GNU make/i;
+    return 1 if $type eq 'bsdmake'
+      and $minus_v =~ /^usage: make \[-BeikNnqrstWwX\]/im;
+    0; # it wasn't whatever you asked
 }
 
 
@@ -287,8 +275,7 @@ the args.  Collectively they will process all the arguments.  Each
 individual line in @cmds will not be longer than the
 $self->max_exec_len being careful to take into account macro expansion.
 
-$cmd should include any switches and repeated initial arguments. If it
-has newlines, they should be already escaped.
+$cmd should include any switches and repeated initial arguments.
 
 If no @args are given, no @cmds will be returned.
 
@@ -335,7 +322,7 @@ sub split_command {
         }
         chop $arg_str;
 
-        push @cmds, $cmd . $self->escape_newlines(" \n$arg_str");
+        push @cmds, $self->escape_newlines("$cmd \n$arg_str");
     } while @args;
 
     return @cmds;
@@ -352,34 +339,6 @@ sub _expand_macros {
 }
 
 
-=head3 make_type
-
-Returns a suitable string describing the type of makefile being written.
-
-=cut
-
-# override if this isn't suitable!
-sub make_type { return 'Unix-style'; }
-
-
-=head3 stashmeta
-
-    my @recipelines = $MM->stashmeta($text, $file);
-
-Generates a set of C<@recipelines> which will result in the literal
-C<$text> ending up in literal C<$file> when the recipe is executed. Call
-it once, with all the text you want in C<$file>. Make macros will not
-be expanded, so the locations will be fixed at configure-time, not
-at build-time.
-
-=cut
-
-sub stashmeta {
-    my($self, $text, $file) = @_;
-    $self->echo($text, $file, { allow_variables => 0, append => 0 });
-}
-
-
 =head3 echo
 
     my @commands = $MM->echo($text);
@@ -399,7 +358,7 @@ all C<$>.
 
 Example of use:
 
-    my $make = join '', map "\t$_\n", $MM->echo($text, $file);
+    my $make = map "\t$_\n", $MM->echo($text, $file);
 
 =cut
 
@@ -512,16 +471,15 @@ Usage might be something like:
     $oneliner = $MM->oneliner('print "Foo\n"');
     $make = '$oneliner > somefile';
 
-Dollar signs in the $perl_code will be protected from make using the
-C<quote_literal> method, unless they are recognised as being a make
-variable, C<$(varname)>, in which case they will be left for make
-to expand. Remember to quote make macros else it might be used as a
-bareword. For example:
+All dollar signs must be doubled in the $perl_code if you expect them
+to be interpreted normally, otherwise it will be considered a make
+macro.  Also remember to quote make macros else it might be used as a
+bareword.  For example:
 
     # Assign the value of the $(VERSION_FROM) make macro to $vf.
-    $oneliner = $MM->oneliner('$vf = "$(VERSION_FROM)"');
+    $oneliner = $MM->oneliner('$$vf = "$(VERSION_FROM)"');
 
-It's currently very simple, and may be expanded sometime in the future
+Its currently very simple and may be expanded sometime in the figure
 to include more flexible code and switches.
 
 
@@ -653,11 +611,6 @@ The blibdirs.ts target is deprecated.  Depend on blibdirs instead.
 
 =cut
 
-sub _xs_list_basenames {
-    my ($self) = @_;
-    map { (my $b = $_) =~ s/\.xs$//; $b } sort keys %{ $self->{XS} };
-}
-
 sub blibdirs_target {
     my $self = shift;
 
@@ -666,14 +619,6 @@ sub blibdirs_target {
                                            bin script
                                            man1dir man3dir
                                           );
-    if ($self->{XSMULTI}) {
-        for my $ext ($self->_xs_list_basenames) {
-            my ($v, $d, $f) = File::Spec->splitpath($ext);
-            my @d = File::Spec->splitdir($d);
-            shift @d if $d[0] eq 'lib';
-            push @dirs, $self->catdir('$(INST_ARCHLIB)', 'auto', @d, $f);
-	}
-    }
 
     my @exists = map { $_.'$(DFSEP).exists' } @dirs;
 
@@ -712,10 +657,6 @@ clean :: clean_subdirs
 ');
 
     my @files = sort values %{$self->{XS}}; # .c files from *.xs files
-    push @files, map {
-	my $file = $_;
-	map { $file.$_ } $self->{OBJ_EXT}, qw(.def _def.old .bs .bso .exp .base);
-    } $self->_xs_list_basenames;
     my @dirs  = qw(blib);
 
     # Normally these are all under blib but they might have been
@@ -912,121 +853,6 @@ MAKE_FRAG
 }
 
 
-=head3 xs_dlsyms_arg
-
-Returns command-line arg(s) to linker for file listing dlsyms to export.
-Defaults to returning empty string, can be overridden by e.g. AIX.
-
-=cut
-
-sub xs_dlsyms_arg {
-    return '';
-}
-
-=head3 xs_dlsyms_ext
-
-Returns file-extension for C<xs_make_dlsyms> method's output file,
-including any "." character.
-
-=cut
-
-sub xs_dlsyms_ext {
-    die "Pure virtual method";
-}
-
-=head3 xs_dlsyms_extra
-
-Returns any extra text to be prepended to the C<$extra> argument of
-C<xs_make_dlsyms>.
-
-=cut
-
-sub xs_dlsyms_extra {
-    '';
-}
-
-=head3 xs_dlsyms_iterator
-
-Iterates over necessary shared objects, calling C<xs_make_dlsyms> method
-for each with appropriate arguments.
-
-=cut
-
-sub xs_dlsyms_iterator {
-    my ($self, $attribs) = @_;
-    if ($self->{XSMULTI}) {
-        my @m;
-        for my $ext ($self->_xs_list_basenames) {
-            my @parts = File::Spec->splitdir($ext);
-            shift @parts if $parts[0] eq 'lib';
-            my $name = join '::', @parts;
-            push @m, $self->xs_make_dlsyms(
-                $attribs,
-                $ext . $self->xs_dlsyms_ext,
-                "$ext.xs",
-                $name,
-                $parts[-1],
-                {}, [], {}, [],
-                $self->xs_dlsyms_extra . q!, 'FILE' => ! . neatvalue($ext),
-            );
-        }
-        return join "\n", @m;
-    } else {
-        return $self->xs_make_dlsyms(
-            $attribs,
-            $self->{BASEEXT} . $self->xs_dlsyms_ext,
-            'Makefile.PL',
-            $self->{NAME},
-            $self->{DLBASE},
-            $attribs->{DL_FUNCS} || $self->{DL_FUNCS} || {},
-            $attribs->{FUNCLIST} || $self->{FUNCLIST} || [],
-            $attribs->{IMPORTS} || $self->{IMPORTS} || {},
-            $attribs->{DL_VARS} || $self->{DL_VARS} || [],
-            $self->xs_dlsyms_extra,
-        );
-    }
-}
-
-=head3 xs_make_dlsyms
-
-    $self->xs_make_dlsyms(
-        \%attribs, # hashref from %attribs in caller
-        "$self->{BASEEXT}.def", # output file for Makefile target
-        'Makefile.PL', # dependency
-        $self->{NAME}, # shared object's "name"
-        $self->{DLBASE}, # last ::-separated part of name
-        $attribs{DL_FUNCS} || $self->{DL_FUNCS} || {}, # various params
-        $attribs{FUNCLIST} || $self->{FUNCLIST} || [],
-        $attribs{IMPORTS} || $self->{IMPORTS} || {},
-        $attribs{DL_VARS} || $self->{DL_VARS} || [],
-        # optional extra param that will be added as param to Mksymlists
-    );
-
-Utility method that returns Makefile snippet to call C<Mksymlists>.
-
-=cut
-
-sub xs_make_dlsyms {
-    my ($self, $attribs, $target, $dep, $name, $dlbase, $funcs, $funclist, $imports, $vars, $extra) = @_;
-    my @m = (
-     "\n$target: $dep\n",
-     q!	$(PERLRUN) -MExtUtils::Mksymlists \\
-     -e "Mksymlists('NAME'=>\"!, $name,
-     q!\", 'DLBASE' => '!,$dlbase,
-     # The above two lines quoted differently to work around
-     # a bug in the 4DOS/4NT command line interpreter.  The visible
-     # result of the bug was files named q('extension_name',) *with the
-     # single quotes and the comma* in the extension build directories.
-     q!', 'DL_FUNCS' => !,neatvalue($funcs),
-     q!, 'FUNCLIST' => !,neatvalue($funclist),
-     q!, 'IMPORTS' => !,neatvalue($imports),
-     q!, 'DL_VARS' => !, neatvalue($vars)
-    );
-    push @m, $extra if defined $extra;
-    push @m, qq!);"\n!;
-    join '', @m;
-}
-
 =head3 dynamic (o)
 
 Defines the dynamic target.
@@ -1038,7 +864,7 @@ sub dynamic {
 
     my($self) = shift;
     '
-dynamic :: $(FIRST_MAKEFILE) config $(INST_BOOT) $(INST_DYNAMIC)
+dynamic :: $(FIRST_MAKEFILE) $(BOOTSTRAP) $(INST_DYNAMIC)
 	$(NOECHO) $(NOOP)
 ';
 }
@@ -1086,14 +912,14 @@ sub manifypods_target {
     }
 
     my $manify = <<END;
-manifypods : pure_all config $dependencies
+manifypods : pure_all $dependencies
 END
 
     my @man_cmds;
-    foreach my $num (qw(1 3)) {
-        my $pods = $self->{"MAN${num}PODS"};
-        my $p2m = sprintf <<'CMD', "\$(MAN${num}SECTION)", "$]" > 5.008 ? " -u" : "";
-	$(NOECHO) $(POD2MAN) --section=%s --perm_rw=$(PERM_RW)%s
+    foreach my $section (qw(1 3)) {
+        my $pods = $self->{"MAN${section}PODS"};
+        my $p2m = sprintf <<CMD, $] > 5.008 ? " -u" : "";
+	\$(NOECHO) \$(POD2MAN) --section=$section --perm_rw=\$(PERM_RW)%s
 CMD
         push @man_cmds, $self->split_command($p2m, map {($_,$pods->{$_})} sort keys %$pods);
     }
@@ -1104,16 +930,12 @@ CMD
     return $manify;
 }
 
-{
-    my $has_cpan_meta;
-    sub _has_cpan_meta {
-        return $has_cpan_meta if defined $has_cpan_meta;
-        return $has_cpan_meta = !!eval {
-            require CPAN::Meta;
-            CPAN::Meta->VERSION(2.112150);
-            1;
-        };
-    }
+sub _has_cpan_meta {
+    return eval {
+      require CPAN::Meta;
+      CPAN::Meta->VERSION(2.112150);
+      1;
+    };
 }
 
 =head3 metafile_target
@@ -1135,18 +957,34 @@ metafile :
 	$(NOECHO) $(NOOP)
 MAKE_FRAG
 
-    my $metadata   = $self->metafile_data(
+    my %metadata   = $self->metafile_data(
         $self->{META_ADD}   || {},
         $self->{META_MERGE} || {},
     );
 
-    my $meta = $self->_fix_metadata_before_conversion( $metadata );
+    _fix_metadata_before_conversion( \%metadata );
 
-    my @write_metayml = $self->stashmeta(
+    # paper over validation issues, but still complain, necessary because
+    # there's no guarantee that the above will fix ALL errors
+    my $meta = eval { CPAN::Meta->create( \%metadata, { lazy_validation => 1 } ) };
+    warn $@ if $@ and
+               $@ !~ /encountered CODE.*, but JSON can only represent references to arrays or hashes/;
+
+    # use the original metadata straight if the conversion failed
+    # or if it can't be stringified.
+    if( !$meta                                                  ||
+        !eval { $meta->as_string( { version => "1.4" } ) }      ||
+        !eval { $meta->as_string }
+    )
+    {
+        $meta = bless \%metadata, 'CPAN::Meta';
+    }
+
+    my @write_metayml = $self->echo(
       $meta->as_string({version => "1.4"}), 'META_new.yml'
     );
-    my @write_metajson = $self->stashmeta(
-      $meta->as_string({version => "2.0"}), 'META_new.json'
+    my @write_metajson = $self->echo(
+      $meta->as_string(), 'META_new.json'
     );
 
     my $metayml = join("\n\t", @write_metayml);
@@ -1167,9 +1005,9 @@ MAKE_FRAG
 
 =head3 _fix_metadata_before_conversion
 
-    $mm->_fix_metadata_before_conversion( \%metadata );
+    _fix_metadata_before_conversion( \%metadata );
 
-Fixes errors in the metadata before it's handed off to L<CPAN::Meta> for
+Fixes errors in the metadata before it's handed off to CPAN::Meta for
 conversion. This hopefully results in something that can be used further
 on, no guarantee is made though.
 
@@ -1178,7 +1016,7 @@ on, no guarantee is made though.
 =cut
 
 sub _fix_metadata_before_conversion {
-    my ( $self, $metadata ) = @_;
+    my ( $metadata ) = @_;
 
     # we should never be called unless this already passed but
     # prefer to be defensive in case somebody else calls this
@@ -1187,24 +1025,18 @@ sub _fix_metadata_before_conversion {
 
     my $bad_version = $metadata->{version} &&
                       !CPAN::Meta::Validator->new->version( 'version', $metadata->{version} );
+
     # just delete all invalid versions
     if( $bad_version ) {
         warn "Can't parse version '$metadata->{version}'\n";
         $metadata->{version} = '';
     }
 
-    my $validator2 = CPAN::Meta::Validator->new( $metadata );
-    my @errors;
-    push @errors, $validator2->errors if !$validator2->is_valid;
-    my $validator14 = CPAN::Meta::Validator->new(
-        {
-            %$metadata,
-            'meta-spec' => { version => 1.4 },
-        }
-    );
-    push @errors, $validator14->errors if !$validator14->is_valid;
+    my $validator = CPAN::Meta::Validator->new( $metadata );
+    return if $validator->is_valid;
+
     # fix non-camelcase custom resource keys (only other trick we know)
-    for my $error ( @errors ) {
+    for my $error ( $validator->errors ) {
         my ( $key ) = ( $error =~ /Custom resource '(.*)' must be in CamelCase./ );
         next if !$key;
 
@@ -1212,39 +1044,17 @@ sub _fix_metadata_before_conversion {
         ( my $new_key = $key ) =~ s/[^_a-zA-Z]//g;
 
         # if that doesn't work, uppercase first one
-        $new_key = ucfirst $new_key if !$validator14->custom_1( $new_key );
+        $new_key = ucfirst $new_key if !$validator->custom_1( $new_key );
 
         # copy to new key if that worked
         $metadata->{resources}{$new_key} = $metadata->{resources}{$key}
-          if $validator14->custom_1( $new_key );
+          if $validator->custom_1( $new_key );
 
         # and delete old one in any case
         delete $metadata->{resources}{$key};
     }
 
-    # paper over validation issues, but still complain, necessary because
-    # there's no guarantee that the above will fix ALL errors
-    my $meta = eval { CPAN::Meta->create( $metadata, { lazy_validation => 1 } ) };
-    warn $@ if $@ and
-               $@ !~ /encountered CODE.*, but JSON can only represent references to arrays or hashes/;
-
-    # use the original metadata straight if the conversion failed
-    # or if it can't be stringified.
-    if( !$meta                                                  ||
-        !eval { $meta->as_string( { version => $METASPEC_V } ) }      ||
-        !eval { $meta->as_string }
-    ) {
-        $meta = bless $metadata, 'CPAN::Meta';
-    }
-
-    my $now_license = $meta->as_struct({ version => 2 })->{license};
-    if ($self->{LICENSE} and $self->{LICENSE} ne 'unknown' and
-        @{$now_license} == 1 and $now_license->[0] eq 'unknown'
-    ) {
-        warn "Invalid LICENSE value '$self->{LICENSE}' ignored\n";
-    }
-
-    $meta;
+    return;
 }
 
 
@@ -1285,10 +1095,10 @@ sub _hash_merge {
 
 =head3 metafile_data
 
-    my $metadata_hashref = $mm->metafile_data(\%meta_add, \%meta_merge);
+    my @metadata_pairs = $mm->metafile_data(\%meta_add, \%meta_merge);
 
 Returns the data which MakeMaker turns into the META.yml file 
-and the META.json file. It is always in version 2.0 of the format.
+and the META.json file.
 
 Values of %meta_add will overwrite any existing metadata in those
 keys.  %meta_merge will be merged with them.
@@ -1299,62 +1109,48 @@ sub metafile_data {
     my $self = shift;
     my($meta_add, $meta_merge) = @_;
 
-    $meta_add ||= {};
-    $meta_merge ||= {};
-
-    my $version = _normalize_version($self->{VERSION});
-    my $unstable = $version =~ /_/ || $self->{DISTVNAME} =~ /-TRIAL\d*$/;
-    my $release_status = $unstable ? 'unstable' : 'stable';
     my %meta = (
         # required
-        abstract     => $self->{ABSTRACT} || 'unknown',
-        author       => defined($self->{AUTHOR}) ? $self->{AUTHOR} : ['unknown'],
-        dynamic_config => 1,
-        generated_by => "ExtUtils::MakeMaker version $ExtUtils::MakeMaker::VERSION",
-        license      => [ $self->{LICENSE} || 'unknown' ],
-        'meta-spec'  => {
-            url         => $METASPEC_URL,
-            version     => $METASPEC_V,
-        },
         name         => $self->{DISTNAME},
-        release_status => $release_status,
-        version      => $version,
+        version      => _normalize_version($self->{VERSION}),
+        abstract     => $self->{ABSTRACT} || 'unknown',
+        license      => $self->{LICENSE} || 'unknown',
+        dynamic_config => 1,
 
         # optional
-        no_index     => { directory => [qw(t inc)] },
+        distribution_type => $self->{PM} ? 'module' : 'script',
+
+        no_index     => {
+            directory   => [qw(t inc)]
+        },
+
+        generated_by => "ExtUtils::MakeMaker version $ExtUtils::MakeMaker::VERSION",
+        'meta-spec'  => {
+            url         => 'http://module-build.sourceforge.net/META-spec-v1.4.html',
+            version     => 1.4
+        },
     );
-    $self->_add_requirements_to_meta(\%meta);
 
-    if (!eval { require JSON::PP; require CPAN::Meta::Converter; CPAN::Meta::Converter->VERSION(2.141170) }) {
-      return \%meta;
+    # The author key is required and it takes a list.
+    $meta{author}   = defined $self->{AUTHOR}    ? $self->{AUTHOR} : [];
+
+    {
+      my $vers = _metaspec_version( $meta_add, $meta_merge );
+      my $method = $vers =~ m!^2!
+               ? '_add_requirements_to_meta_v2'
+               : '_add_requirements_to_meta_v1_4';
+      %meta = $self->$method( %meta );
     }
 
-    # needs to be based on the original version
-    my $v1_add = _metaspec_version($meta_add) !~ /^2/;
-
-    my ($add_v, $merge_v) = map _metaspec_version($_), $meta_add, $meta_merge;
-    for my $frag ($meta_add, $meta_merge) {
-        my $def_v = $frag == $meta_add ? $merge_v : $add_v;
-        $frag = CPAN::Meta::Converter->new($frag, default_version => $def_v)->upgrade_fragment;
-    }
-
-    # if we upgraded a 1.x _ADD fragment, we gave it a prereqs key that
-    # will override all prereqs, which is more than the user asked for;
-    # instead, we'll go inside the prereqs and override all those
     while( my($key, $val) = each %$meta_add ) {
-        if ($v1_add and $key eq 'prereqs') {
-            $meta{$key}{$_} = $val->{$_} for keys %$val;
-        } elsif ($key ne 'meta-spec') {
-            $meta{$key} = $val;
-        }
+        $meta{$key} = $val;
     }
 
     while( my($key, $val) = each %$meta_merge ) {
-        next if $key eq 'meta-spec';
         $self->_hash_merge(\%meta, $key, $val);
     }
 
-    return \%meta;
+    return %meta;
 }
 
 
@@ -1362,61 +1158,84 @@ sub metafile_data {
 
 =cut
 
-sub _add_requirements_to_meta {
-    my ( $self, $meta ) = @_;
-    # Check the original args so we can tell between the user setting it
-    # to an empty hash and it just being initialized.
-    $meta->{prereqs}{configure}{requires} = $self->{ARGS}{CONFIGURE_REQUIRES}
-        ? $self->{CONFIGURE_REQUIRES}
-        : { 'ExtUtils::MakeMaker' => 0, };
-    $meta->{prereqs}{build}{requires} = $self->{ARGS}{BUILD_REQUIRES}
-        ? $self->{BUILD_REQUIRES}
-        : { 'ExtUtils::MakeMaker' => 0, };
-    $meta->{prereqs}{test}{requires} = $self->{TEST_REQUIRES}
-        if $self->{ARGS}{TEST_REQUIRES};
-    $meta->{prereqs}{runtime}{requires} = $self->{PREREQ_PM}
-        if $self->{ARGS}{PREREQ_PM};
-    $meta->{prereqs}{runtime}{requires}{perl} = _normalize_version($self->{MIN_PERL_VERSION})
-        if $self->{MIN_PERL_VERSION};
-}
-
-# spec version of given fragment - if not given, assume 1.4
 sub _metaspec_version {
-  my ( $meta ) = @_;
-  return $meta->{'meta-spec'}->{version}
-    if defined $meta->{'meta-spec'}
-       and defined $meta->{'meta-spec'}->{version};
+  my ( $meta_add, $meta_merge ) = @_;
+  return $meta_add->{'meta-spec'}->{version}
+    if defined $meta_add->{'meta-spec'}
+       and defined $meta_add->{'meta-spec'}->{version};
+  return $meta_merge->{'meta-spec'}->{version}
+    if defined $meta_merge->{'meta-spec'}
+       and  defined $meta_merge->{'meta-spec'}->{version};
   return '1.4';
 }
 
 sub _add_requirements_to_meta_v1_4 {
-    my ( $self, $meta ) = @_;
+    my ( $self, %meta ) = @_;
+
     # Check the original args so we can tell between the user setting it
     # to an empty hash and it just being initialized.
     if( $self->{ARGS}{CONFIGURE_REQUIRES} ) {
-        $meta->{configure_requires} = $self->{CONFIGURE_REQUIRES};
+        $meta{configure_requires} = $self->{CONFIGURE_REQUIRES};
     } else {
-        $meta->{configure_requires} = {
+        $meta{configure_requires} = {
             'ExtUtils::MakeMaker'       => 0,
         };
     }
+
     if( $self->{ARGS}{BUILD_REQUIRES} ) {
-        $meta->{build_requires} = $self->{BUILD_REQUIRES};
+        $meta{build_requires} = $self->{BUILD_REQUIRES};
     } else {
-        $meta->{build_requires} = {
+        $meta{build_requires} = {
             'ExtUtils::MakeMaker'       => 0,
         };
     }
+
     if( $self->{ARGS}{TEST_REQUIRES} ) {
-        $meta->{build_requires} = {
-          %{ $meta->{build_requires} },
+        $meta{build_requires} = {
+          %{ $meta{build_requires} },
           %{ $self->{TEST_REQUIRES} },
         };
     }
-    $meta->{requires} = $self->{PREREQ_PM}
+
+    $meta{requires} = $self->{PREREQ_PM}
         if defined $self->{PREREQ_PM};
-    $meta->{requires}{perl} = _normalize_version($self->{MIN_PERL_VERSION})
+    $meta{requires}{perl} = _normalize_version($self->{MIN_PERL_VERSION})
         if $self->{MIN_PERL_VERSION};
+
+    return %meta;
+}
+
+sub _add_requirements_to_meta_v2 {
+    my ( $self, %meta ) = @_;
+
+    # Check the original args so we can tell between the user setting it
+    # to an empty hash and it just being initialized.
+    if( $self->{ARGS}{CONFIGURE_REQUIRES} ) {
+        $meta{prereqs}{configure}{requires} = $self->{CONFIGURE_REQUIRES};
+    } else {
+        $meta{prereqs}{configure}{requires} = {
+            'ExtUtils::MakeMaker'       => 0,
+        };
+    }
+
+    if( $self->{ARGS}{BUILD_REQUIRES} ) {
+        $meta{prereqs}{build}{requires} = $self->{BUILD_REQUIRES};
+    } else {
+        $meta{prereqs}{build}{requires} = {
+            'ExtUtils::MakeMaker'       => 0,
+        };
+    }
+
+    if( $self->{ARGS}{TEST_REQUIRES} ) {
+        $meta{prereqs}{test}{requires} = $self->{TEST_REQUIRES};
+    }
+
+    $meta{prereqs}{runtime}{requires} = $self->{PREREQ_PM}
+        if $self->{ARGS}{PREREQ_PM};
+    $meta{prereqs}{runtime}{requires}{perl} = _normalize_version($self->{MIN_PERL_VERSION})
+        if $self->{MIN_PERL_VERSION};
+
+    return %meta;
 }
 
 # Adapted from Module::Build::Base
@@ -1425,7 +1244,7 @@ sub _normalize_version {
   $version = 0 unless defined $version;
 
   if ( ref $version eq 'version' ) { # version objects
-    $version = $version->stringify;
+    $version = $version->is_qv ? $version->normal : $version->stringify;
   }
   elsif ( $version =~ /^[^v][^.]*\.[^.]+\./ ) { # no leading v, multiple dots
     # normalize string tuples without "v": "1.2.3" -> "v1.2.3"
@@ -1598,12 +1417,12 @@ sub distmeta_target {
       $self->oneliner(<<'CODE', ['-MExtUtils::Manifest=maniadd']),
 exit unless -e q{META.yml};
 eval { maniadd({q{META.yml} => q{Module YAML meta-data (added by MakeMaker)}}) }
-    or die "Could not add META.yml to MANIFEST: ${'@'}"
+    or print "Could not add META.yml to MANIFEST: $${'@'}\n"
 CODE
       $self->oneliner(<<'CODE', ['-MExtUtils::Manifest=maniadd'])
 exit unless -f q{META.json};
 eval { maniadd({q{META.json} => q{Module JSON meta-data (added by MakeMaker)}}) }
-    or die "Could not add META.json to MANIFEST: ${'@'}"
+    or print "Could not add META.json to MANIFEST: $${'@'}\n"
 CODE
     );
 
@@ -1636,15 +1455,21 @@ sub mymeta {
     my $v2 = 1;
 
     unless ( $mymeta ) {
-        $mymeta = $self->metafile_data(
+        my @metadata = $self->metafile_data(
             $self->{META_ADD}   || {},
             $self->{META_MERGE} || {},
         );
+        $mymeta = {@metadata};
         $v2 = 0;
     }
 
     # Overwrite the non-configure dependency hashes
-    $self->_add_requirements_to_meta($mymeta);
+
+    my $method = $v2
+               ? '_add_requirements_to_meta_v2'
+               : '_add_requirements_to_meta_v1_4';
+
+    $mymeta = { $self->$method( %$mymeta ) };
 
     $mymeta->{dynamic_config} = 0;
 
@@ -1673,7 +1498,7 @@ sub _mymeta_from_meta {
     # rolled their own tarball rather than using "make dist".
     if ($meta->{generated_by} &&
         $meta->{generated_by} =~ /ExtUtils::MakeMaker version ([\d\._]+)/) {
-        my $eummv = do { no warnings; $1+0; };
+        my $eummv = do { local $^W = 0; $1+0; };
         if ($eummv < 6.2501) {
             return;
         }
@@ -1696,9 +1521,13 @@ sub write_mymeta {
 
     return unless _has_cpan_meta();
 
-    my $meta_obj = $self->_fix_metadata_before_conversion( $mymeta );
+    _fix_metadata_before_conversion( $mymeta );
 
-    $meta_obj->save( 'MYMETA.json', { version => "2.0" } );
+    # this can still blow up
+    # not sure if i should just eval this and skip file creation if it
+    # blows up
+    my $meta_obj = CPAN::Meta->new( $mymeta, { lazy_validation => 1 } );
+    $meta_obj->save( 'MYMETA.json' );
     $meta_obj->save( 'MYMETA.yml', { version => "1.4" } );
     return 1;
 }
@@ -1736,8 +1565,8 @@ sub realclean {
     }
 
     # Occasionally files are repeated several times from different sources
-    { my(%f) = map { ($_ => 1) } @files;  @files = sort keys %f; }
-    { my(%d) = map { ($_ => 1) } @dirs;   @dirs  = sort keys %d; }
+    { my(%f) = map { ($_ => 1) } @files;  @files = keys %f; }
+    { my(%d) = map { ($_ => 1) } @dirs;   @dirs  = keys %d; }
 
     my $rm_cmd  = join "\n\t", map { "$_" }
                     $self->split_command('- $(RM_F)',  @files);
@@ -1746,7 +1575,7 @@ sub realclean {
 
     my $m = sprintf <<'MAKE', $rm_cmd, $rmf_cmd;
 # Delete temporary files (via clean) and also delete dist files
-realclean purge :: realclean_subdirs
+realclean purge ::  clean realclean_subdirs
 	%s
 	%s
 MAKE
@@ -1768,20 +1597,28 @@ target to call realclean on any subdirectories which contain Makefiles.
 
 sub realclean_subdirs_target {
     my $self = shift;
-    my @m = <<'EOF';
-# so clean is forced to complete before realclean_subdirs runs
-realclean_subdirs : clean
-EOF
-    return join '', @m, "\t\$(NOECHO) \$(NOOP)\n" unless @{$self->{DIR}};
+
+    return <<'NOOP_FRAG' unless @{$self->{DIR}};
+realclean_subdirs :
+	$(NOECHO) $(NOOP)
+NOOP_FRAG
+
+    my $rclean = "realclean_subdirs :\n";
+
     foreach my $dir (@{$self->{DIR}}) {
         foreach my $makefile ('$(MAKEFILE_OLD)', '$(FIRST_MAKEFILE)' ) {
-            my $subrclean .= $self->oneliner(_sprintf562 <<'CODE', $dir, $makefile);
-chdir '%1$s';  system '$(MAKE) $(USEMAKEFILE) %2$s realclean' if -f '%2$s';
+            my $subrclean .= $self->oneliner(sprintf <<'CODE', $dir, ($makefile) x 2);
+chdir '%s';  system '$(MAKE) $(USEMAKEFILE) %s realclean' if -f '%s';
 CODE
-            push @m, "\t- $subrclean\n";
+
+            $rclean .= sprintf <<'RCLEAN', $subrclean;
+	- %s
+RCLEAN
+
         }
     }
-    return join '', @m;
+
+    return $rclean;
 }
 
 
@@ -1820,7 +1657,7 @@ sub distsignature_target {
 
     my $add_sign = $self->oneliner(<<'CODE', ['-MExtUtils::Manifest=maniadd']);
 eval { maniadd({q{SIGNATURE} => q{Public-key signature (added by MakeMaker)}}) }
-    or die "Could not add SIGNATURE to MANIFEST: ${'@'}"
+    or print "Could not add SIGNATURE to MANIFEST: $${'@'}\n"
 CODE
 
     my $sign_dist        = $self->cd('$(DISTVNAME)' => 'cpansign -s');
@@ -1831,7 +1668,7 @@ CODE
     my $add_sign_to_dist = $self->cd('$(DISTVNAME)' => $add_sign );
 
     return sprintf <<'MAKE', $add_sign_to_dist, $touch_sig, $sign_dist
-distsignature : distmeta
+distsignature : create_distdir
 	$(NOECHO) %s
 	$(NOECHO) %s
 	%s
@@ -1854,7 +1691,7 @@ sub special_targets {
     my $make_frag = <<'MAKE_FRAG';
 .SUFFIXES : .xs .c .C .cpp .i .s .cxx .cc $(OBJ_EXT)
 
-.PHONY: all config static dynamic test linkext manifest blibdirs clean realclean disttest distdir pure_all subdirs clean_subdirs makemakerdflt manifypods realclean_subdirs subdirs_dynamic subdirs_pure_nolink subdirs_static subdirs-test_dynamic subdirs-test_static test_dynamic test_static
+.PHONY: all config static dynamic test linkext manifest blibdirs clean realclean disttest distdir
 
 MAKE_FRAG
 
@@ -2217,9 +2054,7 @@ sub init_INSTALL_from_INSTALL_BASE {
             my $key = "INSTALL".$dir.$uc_thing;
 
             $install{$key} ||=
-                ($thing =~ /^man.dir$/ and not $Config{lc $key})
-                ? 'none'
-                : $self->catdir('$(INSTALL_BASE)', @{$map{$thing}});
+              $self->catdir('$(INSTALL_BASE)', @{$map{$thing}});
         }
     }
 
@@ -2421,7 +2256,7 @@ Initializes the macro definitions having to do with compiling and
 linking used by tools_other() and places them in the $MM object.
 
 If there is no description, its the same as the parameter to
-WriteMakefile() documented in L<ExtUtils::MakeMaker>.
+WriteMakefile() documented in ExtUtils::MakeMaker.
 
 =cut
 
@@ -2433,12 +2268,13 @@ sub init_others {
     $self->{LIBS} = $self->_fix_libs($self->{LIBS});
 
     # Compute EXTRALIBS, BSLOADLIBS and LDLOADLIBS from $self->{LIBS}
-    foreach my $libs ( @{$self->{LIBS}} ) {
+    foreach my $libs ( @{$self->{LIBS}} ){
         $libs =~ s/^\s*(.*\S)\s*$/$1/; # remove leading and trailing whitespace
-        my @libs = $self->extliblist($libs);
-        if (grep $_, @libs[0..2]) {
+        my(@libs) = $self->extliblist($libs);
+        if ($libs[0] or $libs[1] or $libs[2]){
             # LD_RUN_PATH now computed by ExtUtils::Liblist
-            @$self{qw(EXTRALIBS BSLOADLIBS LDLOADLIBS LD_RUN_PATH)} = @libs;
+            ($self->{EXTRALIBS},  $self->{BSLOADLIBS},
+             $self->{LDLOADLIBS}, $self->{LD_RUN_PATH}) = @libs;
             last;
         }
     }
@@ -2446,7 +2282,7 @@ sub init_others {
     if ( $self->{OBJECT} ) {
         $self->{OBJECT} = join(" ", @{$self->{OBJECT}}) if ref $self->{OBJECT};
         $self->{OBJECT} =~ s!\.o(bj)?\b!\$(OBJ_EXT)!g;
-    } elsif ( ($self->{MAGICXS} || $self->{XSMULTI}) && @{$self->{O_FILES}||[]} ) {
+    } elsif ( $self->{MAGICXS} && @{$self->{O_FILES}||[]} ) {
         $self->{OBJECT} = join(" ", @{$self->{O_FILES}});
         $self->{OBJECT} =~ s!\.o(bj)?\b!\$(OBJ_EXT)!g;
     } else {
@@ -2499,10 +2335,6 @@ sub tools_other {
     my($self) = shift;
     my @m;
 
-    my $is_nmake = $self->is_make_type('nmake');
-    push @m, <<'EOF' if $is_nmake;
-EUMM_NMAKE_HASH = ^# # to get hash character into strings - yes, horrible
-EOF
     # We set PM_FILTER as late as possible so it can see all the earlier
     # on macro-order sensitive makes such as nmake.
     for my $tool (qw{ SHELL CHMOD CP MV NOOP NOECHO RM_F RM_RF TEST_F TOUCH
@@ -2519,14 +2351,8 @@ EOF
                       CP_NONEMPTY
                     } )
     {
-        next unless defined(my $value = $self->{$tool});
-        # https://learn.microsoft.com/en-us/cpp/build/reference/contents-of-a-makefile?view=msvc-170#special-characters-in-a-makefile
-        if ($is_nmake) {
-          $value =~ s/#/\$(EUMM_NMAKE_HASH)/g
-        } else {
-          $value =~ s/#/\\#/g
-        }
-        push @m, "$tool = $value\n";
+        next unless defined $self->{$tool};
+        push @m, "$tool = $self->{$tool}\n";
     }
 
     return join "", @m;
@@ -2781,7 +2607,7 @@ END
 
 =head2 File::Spec wrappers
 
-ExtUtils::MM_Any is a subclass of L<File::Spec>.  The methods noted here
+ExtUtils::MM_Any is a subclass of File::Spec.  The methods noted here
 override File::Spec.
 
 
@@ -2824,50 +2650,38 @@ sub find_tests {
   my $tests = $mm->find_tests_recursive;
 
 Returns a string suitable for feeding to the shell to return all
-tests in t/ but recursively. Equivalent to
-
-  my $tests = $mm->find_tests_recursive_in('t');
+tests in t/ but recursively.
 
 =cut
 
 sub find_tests_recursive {
-    my $self = shift;
-    return $self->find_tests_recursive_in('t');
-}
-
-=head3 find_tests_recursive_in
-
-  my $tests = $mm->find_tests_recursive_in($dir);
-
-Returns a string suitable for feeding to the shell to return all
-tests in $dir recursively.
-
-=cut
-
-sub find_tests_recursive_in {
-    my($self, $dir) = @_;
-    return '' unless -d $dir;
+    my($self) = shift;
+    return '' unless -d 't';
 
     require File::Find;
 
-    my $base_depth = grep { $_ ne '' } File::Spec->splitdir( (File::Spec->splitpath($dir))[1] );
-    my %depths;
+    my %testfiles;
 
     my $wanted = sub {
         return unless m!\.t$!;
         my ($volume,$directories,$file) =
             File::Spec->splitpath( $File::Find::name  );
-        my $depth = grep { $_ ne '' } File::Spec->splitdir( $directories );
-        $depth -= $base_depth;
-        $depths{ $depth } = 1;
+        my @dirs = File::Spec->splitdir( $directories );
+        for ( @dirs ) {
+          next if $_ eq 't';
+          unless ( $_ ) {
+            $_ = '*.t';
+            next;
+          }
+          $_ = '*';
+        }
+        my $testfile = join '/', @dirs;
+        $testfiles{ $testfile } = 1;
     };
 
-    File::Find::find( $wanted, $dir );
+    File::Find::find( $wanted, 't' );
 
-    return join ' ',
-        map { $dir . '/*' x $_ . '.t' }
-        sort { $a <=> $b }
-        keys %depths;
+    return join ' ', sort keys %testfiles;
 }
 
 =head3 extra_clean_files
@@ -2913,19 +2727,13 @@ Takes a path to a file or dir and returns an empty string if we don't
 want to include this file in the library.  Otherwise it returns the
 the $path unchanged.
 
-Mainly used to exclude version control administrative directories
-and base-level F<README.pod> from installation.
+Mainly used to exclude version control administrative directories from
+installation.
 
 =cut
 
 sub libscan {
     my($self,$path) = @_;
-
-    if ($path =~ m<^README\.pod$>i) {
-        warn "WARNING: Older versions of ExtUtils::MakeMaker may errantly install $path as part of this distribution. It is recommended to avoid using this path in CPAN modules.\n";
-        return '';
-    }
-
     my($dirs,$file) = ($self->splitpath($path))[1,2];
     return '' if grep /^(?:RCS|CVS|SCCS|\.svn|_darcs)$/,
                      $self->splitdir($dirs), $file;
@@ -2947,39 +2755,6 @@ sub platform_constants {
     return '';
 }
 
-=head3 post_constants (o)
-
-Returns an empty string per default. Dedicated to overrides from
-within Makefile.PL after all constants have been defined.
-
-=cut
-
-sub post_constants {
-    "";
-}
-
-=head3 post_initialize (o)
-
-Returns an empty string per default. Used in Makefile.PLs to add some
-chunk of text to the Makefile after the object is initialized.
-
-=cut
-
-sub post_initialize {
-    "";
-}
-
-=head3 postamble (o)
-
-Returns an empty string. Can be used in Makefile.PLs to write some
-text to the Makefile at the end.
-
-=cut
-
-sub postamble {
-    "";
-}
-
 =begin private
 
 =head3 _PREREQ_PRINT
@@ -3015,7 +2790,7 @@ sub _PREREQ_PRINT {
 Implements PRINT_PREREQ, a slightly different version of PREREQ_PRINT
 added by Redhat to, I think, support generating RPMs from Perl modules.
 
-Should not include BUILD_REQUIRES as RPMs do not include them.
+Should not include BUILD_REQUIRES as RPMs do not incluide them.
 
 Refactored out of MakeMaker->new().
 
@@ -3039,6 +2814,24 @@ sub _PRINT_PREREQ {
 }
 
 
+=begin private
+
+=head3 _all_prereqs
+
+  my $prereqs = $self->_all_prereqs;
+
+Returns a hash ref of both PREREQ_PM and BUILD_REQUIRES.
+
+=end private
+
+=cut
+
+sub _all_prereqs {
+    my $self = shift;
+
+    return { %{$self->{PREREQ_PM}}, %{$self->{BUILD_REQUIRES}} };
+}
+
 =begin private
 
 =head3 _perl_header_files
