@@ -1,15 +1,13 @@
 package ExtUtils::MM_Darwin;
 
 use strict;
-use warnings;
 
 BEGIN {
     require ExtUtils::MM_Unix;
     our @ISA = qw( ExtUtils::MM_Unix );
 }
 
-our $VERSION = '7.77_03';
-$VERSION =~ tr/_//d;
+our $VERSION = '7.04';
 
 
 =head1 NAME
@@ -22,10 +20,10 @@ ExtUtils::MM_Darwin - special behaviors for OS X
 
 =head1 DESCRIPTION
 
-See L<ExtUtils::MM_Unix> or L<ExtUtils::MM_Any> for documentation on the
+See L<ExtUtils::MM_Unix> for L<ExtUtils::MM_Any> for documentation on the
 methods overridden here.
 
-=head2 Overridden Methods
+=head2 Overriden Methods
 
 =head3 init_dist
 
