@@ -1,10 +1,8 @@
 package ExtUtils::MM_MacOS;
 
 use strict;
-use warnings;
 
-our $VERSION = '7.77_03';
-$VERSION =~ tr/_//d;
+our $VERSION = '7.04';
 
 sub new {
     die 'MacOS Classic (MacPerl) is no longer supported by MakeMaker';
