@@ -1,9 +1,7 @@
 package ExtUtils::MM_VOS;
 
 use strict;
-use warnings;
-our $VERSION = '7.77_03';
-$VERSION =~ tr/_//d;
+our $VERSION = '7.04';
 
 require ExtUtils::MM_Unix;
 our @ISA = qw(ExtUtils::MM_Unix);
@@ -20,10 +18,10 @@ ExtUtils::MM_VOS - VOS specific subclass of ExtUtils::MM_Unix
 
 =head1 DESCRIPTION
 
-This is a subclass of L<ExtUtils::MM_Unix> which contains functionality for
+This is a subclass of ExtUtils::MM_Unix which contains functionality for
 VOS.
 
-Unless otherwise stated it works just like ExtUtils::MM_Unix.
+Unless otherwise stated it works just like ExtUtils::MM_Unix
 
 =head2 Overridden methods
 
