@@ -7,12 +7,10 @@
 package ExtUtils::MakeMaker::version::regex;
 
 use strict;
-use warnings;
 
 use vars qw($VERSION $CLASS $STRICT $LAX);
 
-$VERSION = '7.77_03';
-$VERSION =~ tr/_//d;
+$VERSION = '7.04';
 
 #--------------------------------------------------------------------------#
 # Version regexp components
